@@ -27,8 +27,8 @@ from pytz.tzinfo import DstTzInfo, StaticTzInfo  # noqa
 
 # I test for expected version to ensure the correct version of pytz is
 # actually being tested.
-EXPECTED_VERSION = '2019.3'
-EXPECTED_OLSON_VERSION = '2019c'
+EXPECTED_VERSION = '2021.1'
+EXPECTED_OLSON_VERSION = '2021a'
 
 fmt = '%Y-%m-%d %H:%M:%S %Z%z'
 
@@ -859,6 +859,7 @@ def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(doctest.DocTestSuite('pytz'))
     suite.addTest(doctest.DocTestSuite('pytz.tzinfo'))
+    suite.addTest(doctest.DocTestSuite('pytz.exceptions'))
     import test_tzinfo
     suite.addTest(unittest.defaultTestLoader.loadTestsFromModule(test_tzinfo))
     return suite
